searchData={"items":[{"type":"module","title":"SimpleFeatureFlags","doc":"This module includes functions for checking whether a feature is enabled (`enabled?/1`), and for introspecting configuration (`current_configuration_to_string/0`).","ref":"SimpleFeatureFlags.html"},{"type":"function","title":"SimpleFeatureFlags.current_configuration_to_string/0","doc":"Return the current configuration as a human-friendly string.","ref":"SimpleFeatureFlags.html#current_configuration_to_string/0"},{"type":"function","title":"Examples - SimpleFeatureFlags.current_configuration_to_string/0","doc":"iex> SimpleFeatureFlags.current_configuration_to_string()\n    \"Current Deployment Environment: :test\\nFeatures:\\n - test_feature_1, enabled in [:all]\\n - test_feature_2, enabled in :all\\n - test_feature_3, enabled in [:test]\\n - test_feature_4, enabled in [:staging, :test, :production]\\n - test_feature_5, enabled in [:staging, :production]\\n - test_feature_6, enabled in []\\n\"","ref":"SimpleFeatureFlags.html#current_configuration_to_string/0-examples"},{"type":"function","title":"SimpleFeatureFlags.enabled?/1","doc":"Is feature x enabled in the current deployment environment?","ref":"SimpleFeatureFlags.html#enabled?/1"},{"type":"function","title":"Examples - SimpleFeatureFlags.enabled?/1","doc":"iex> SimpleFeatureFlags.enabled?(:test_feature_1)\n    true","ref":"SimpleFeatureFlags.html#enabled?/1-examples"},{"type":"extras","title":"README","doc":"# README\n\nSimpleFeatureFlags provides a simple way to enable or disable features, per-environment, using application configuration.","ref":"readme.html"},{"type":"extras","title":"Code Example - README","doc":"#","ref":"readme.html#code-example"},{"type":"extras","title":"Put your feature behind the \"enabled?\" - README","doc":"```elixir\ndef compute_pi() do\n  if SimpleFeatureFlags.enabled?(:new_algorithm) do\n    compute_pi_new_algorithm()\n  else\n    3.14\n  end\nend\n```\n\n#","ref":"readme.html#put-your-feature-behind-the-enabled"},{"type":"extras","title":"Enable the feature in some environments - README","doc":"`config/runtime.exs`\n```elixir\n...\nconfig :simple_feature_flags, :flags, %{\n  ...\n  features: %{\n    new_algorithm: %{enabled_in: [:localhost, :staging]}\n    ...\n  }\n  ...\n}\n...\n```\n\n#","ref":"readme.html#enable-the-feature-in-some-environments"},{"type":"extras","title":"Optionally, include configuration information in application log - README","doc":"`lib/myapp/application.ex`\n\n```elixir\ndefmodule MyApp.Application do\n\n  require Logger\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    Logger.info(SimpleFeatureFlags.current_configuration_to_string())\n    children =\n    ...\n```\n\nHere is an example of the output:\n\n```text\n  Current Deployment Environment: :test\n  Features:\n  - new_algorithm, enabled in [:localhost, :staging]\n  - new_ui, enabled in [:localhost]\n```\n\n#","ref":"readme.html#optionally-include-configuration-information-in-application-log"},{"type":"extras","title":"A complete configuration example - README","doc":"`config/runtime.exs`\n```elixir\n...\nconfig :simple_feature_flags, :flags, %{\n  current_deployment_environment: :test,\n  features: %{\n    new_algorithm: %{enabled_in: [:localhost, :staging]},\n    new_ui: %{enabled_in: [:localhost]}\n  }\n}\n...\n```\n\n#","ref":"readme.html#a-complete-configuration-example"},{"type":"extras","title":"Enabling or disabling a feature - README","doc":"To turn a feature or or off, update configuration and restart your application. For example, to enable the `new_algorithm` feature in production, add `:production` to the list of `enabled_in`: \n\n```elixir\n    ...\n        new_algorithm: %{enabled_in: [:localhost, :staging, :production]}\n    ...\n```","ref":"readme.html#enabling-or-disabling-a-feature"},{"type":"extras","title":"Installation - README","doc":"The package can be installed by adding `simple_feature_flags` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simple_feature_flags, \"~> 0.1\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2023 Mark Markaryan\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}